@@ -11,7 +11,7 @@ import pandas as pd
 import numpy as np
 import copy
 from tabulate import tabulate
-from constants import *
+from .constants import *
 
 class MCDA:
     """
